#ifndef SRMRENDERMODEDUMB_H
#define SRMRENDERMODEDUMB_H

#include <SRMTypes.h>

#ifdef __cplusplus
extern "C" {
#endif

void srmRenderModeDumbSetInterface(SRMConnector *connector);

#ifdef __cplusplus
}
#endif

#endif // SRMRENDERMODEDUMB_H
